PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Math/IPoint2.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Functions
IPoint2.hpp File Reference
`#include "Defs.hpp"`
`#include <cmath>`
`#include <iostream>`

Go to the source code of this file.

## Data Structures
class | IVector_2
class | IPoint_2

## Functions
std::ostream & | operator<< (std::ostream &os, const IVector_2 &v)
std::ostream & | operator<< (std::ostream &os, const IPoint_2 &P)

## Function Documentation

## ◆ operator<<() [1/2]

std::ostream & operator<< | ( | std::ostream & | os,
|  | const IPoint_2 & | P )
| inline

## ◆ operator<<() [2/2]

std::ostream & operator<< | ( | std::ostream & | os,
|  | const IVector_2 & | v )
| inline